==> higlass-1.12.2.tgz: package/app/scripts/utils/index.js <==
export { default as absToChr } from './abs-to-chr';
export { default as accessorTransposition } from './accessor-transposition';
export { default as addArrays } from './add-arrays';
export { default as addClass } from './add-class';
export { default as base64ToCanvas } from './base64-to-canvas';
export { default as chromInfoBisector } from './chrom-info-bisector';
export { default as chrToAbs } from './chr-to-abs';
export { default as cloneEvent } from './clone-event';
export { default as colorDomainToRgbaArray } from './color-domain-to-rgba-array';
export { default as colorToHex } from './color-to-hex';
export { default as colorToRgba } from './color-to-rgba';
export { default as dataToGenomicLoci } from './data-to-genomic-loci';
export { default as debounce } from './debounce';
export { default as decToHexStr } from './dec-to-hex-str';
export { default as dictFromTuples } from './dict-from-tuples';
export { default as dictItems } from './dict-items';
export { default as dictKeys } from './dict-keys';
export { default as dictValues } from './dict-values';
export { default as download } from './download';
export { default as fillInMinWidths } from './fill-in-min-widths';
export { default as flatten } from './flatten';
export { default as forEach } from './for-each';
export { default as forwardEvent } from './forward-event';
export { default as genomeLociToPixels } from './genome-loci-to-pixels';
export { default as genomicRangeToChromosomeChunks } from './genomic-range-to-chromosome-chunks';
export { default as getDefaultTrackForDatatype } from './get-default-track-for-datatype';
export { default as getElementDim } from './get-element-dim';
export { default as getTrackByUid } from './get-track-by-uid';
export { default as getTrackConfFromHGC } from './get-track-conf-from-hgc';
export { default as getTrackObjById } from './get-track-obj-by-id';
export { default as getTrackPositionByUid } from './get-track-position-by-uid';
export { default as getXylofon } from './get-xylofon';
export { default as gradient } from './gradient';
export { default as hasClass } from './has-class';
export { default as hasParent } from './has-parent';
export { default as hexStrToInt } from './hex-string-to-int';
export { default as intoTheVoid } from './into-the-void';
export { default as isTrackOrChildTrack } from './is-track-or-child-track';
export { default as isWithin } from './is-within';
export { default as latToY } from './lat-to-y';
export { default as loadChromInfos } from './load-chrom-infos';
export { default as lngToX } from './lng-to-x';
export { default as map } from './map';
export { default as max } from './max';
export { default as maxNonZero } from './max-non-zero';
export { default as min } from './min';
export { default as minNonZero } from './min-non-zero';
export { default as mod } from './mod';
export { default as ndarrayAssign } from './ndarray-assign';
export { default as ndarrayFlatten } from './ndarray-flatten';
export { default as ndarrayToList } from './ndarray-to-list';
export { default as numericifyVersion } from './numericify-version';
export { default as objVals } from './obj-vals';
export { default as or } from './or';
export { default as parseChromsizesRows } from './parse-chromsizes-rows';
export { default as pixiTextToSvg } from './pixi-text-to-svg';
export { default as q } from './q';
export { default as reduce } from './reduce';
export { default as rangeQuery2d } from './range-query-2d';
export { default as relToAbsChromPos } from './rel-to-abs-chrom-pos';
export { default as removeClass } from './remove-class';
export { default as resetD3BrushStyle } from './reset-d3-brush-style';
export { default as rgbToHex } from './rgb-to-hex';
export { default as scalesCenterAndK } from './scales-center-and-k';
export { default as scalesToGenomeLoci } from './scales-to-genome-loci';
export { default as showMousePosition } from './show-mouse-position';
export { default as some } from './some';
export { default as sum } from './sum';
export { default as svgLine } from './svg-line';
export { default as throttleAndDebounce } from './throttle-and-debounce';
export { default as tileToCanvas } from './tile-to-canvas';
export { default as timeout } from './timeout';
export { default as totalTrackPixelHeight } from './total-track-pixel-height';
export { default as toVoid } from './to-void';
export { default as trimTrailingSlash } from './trim-trailing-slash';
export { default as valueToColor } from './value-to-color';
export { default as expandCombinedTracks } from './expand-combined-tracks';
export { default as segmentsToRows } from './segments-to-rows';
export { default as visitPositionedTracks } from './visit-positioned-tracks';
export { default as visitTracks } from './visit-tracks';
export { default as trackUtils } from './track-utils';
export { default as DenseDataExtrema1D } from './DenseDataExtrema1D';
export { default as DenseDataExtrema2D } from './DenseDataExtrema2D';

export {
  getTrackObjectFromHGC,
  getTrackRenderer,
  getTiledPlot,
} from './get-higlass-components';
export {
  changeOptions,
  waitForJsonComplete,
  waitForTilesLoaded,
  waitForTransitionsFinished,
  mountHGComponent,
  mountHGComponentAsync,
  removeHGComponent,
} from './test-helpers';

==> higlass-1.12.4.tgz: package/app/scripts/utils/index.js <==
export { default as absToChr } from './abs-to-chr';
export { default as accessorTransposition } from './accessor-transposition';
export { default as addArrays } from './add-arrays';
export { default as addClass } from './add-class';
export { default as base64ToCanvas } from './base64-to-canvas';
export { default as chromInfoBisector } from './chrom-info-bisector';
export { default as chrToAbs } from './chr-to-abs';
export { default as cloneEvent } from './clone-event';
export { default as colorDomainToRgbaArray } from './color-domain-to-rgba-array';
export { default as colorToHex } from './color-to-hex';
export { default as colorToRgba } from './color-to-rgba';
export { default as dataToGenomicLoci } from './data-to-genomic-loci';
export { default as debounce } from './debounce';
export { default as decToHexStr } from './dec-to-hex-str';
export { default as dictFromTuples } from './dict-from-tuples';
export { default as dictItems } from './dict-items';
export { default as dictKeys } from './dict-keys';
export { default as dictValues } from './dict-values';
export { default as download } from './download';
export { default as fillInMinWidths } from './fill-in-min-widths';
export { default as flatten } from './flatten';
export { default as forEach } from './for-each';
export { default as forwardEvent } from './forward-event';
export { default as genomeLociToPixels } from './genome-loci-to-pixels';
export { default as genomicRangeToChromosomeChunks } from './genomic-range-to-chromosome-chunks';
export { default as getDefaultTrackForDatatype } from './get-default-track-for-datatype';
export { default as getElementDim } from './get-element-dim';
export { default as getTrackByUid } from './get-track-by-uid';
export { default as getTrackConfFromHGC } from './get-track-conf-from-hgc';
export { default as getTrackObjById } from './get-track-obj-by-id';
export { default as getTrackPositionByUid } from './get-track-position-by-uid';
export { default as getXylofon } from './get-xylofon';
export { default as gradient } from './gradient';
export { default as hasClass } from './has-class';
export { default as hasParent } from './has-parent';
export { default as hexStrToInt } from './hex-string-to-int';
export { default as intoTheVoid } from './into-the-void';
export { default as isTrackOrChildTrack } from './is-track-or-child-track';
export { default as isWithin } from './is-within';
export { default as latToY } from './lat-to-y';
export { default as loadChromInfos } from './load-chrom-infos';
export { default as lngToX } from './lng-to-x';
export { default as map } from './map';
export { default as max } from './max';
export { default as maxNonZero } from './max-non-zero';
export { default as min } from './min';
export { default as minNonZero } from './min-non-zero';
export { default as mod } from './mod';
export { default as ndarrayAssign } from './ndarray-assign';
export { default as ndarrayFlatten } from './ndarray-flatten';
export { default as ndarrayToList } from './ndarray-to-list';
export { default as numericifyVersion } from './numericify-version';
export { default as objVals } from './obj-vals';
export { default as or } from './or';
export { default as parseChromsizesRows } from './parse-chromsizes-rows';
export { default as pixiTextToSvg } from './pixi-text-to-svg';
export { default as q } from './q';
export { default as reduce } from './reduce';
export { default as rangeQuery2d } from './range-query-2d';
export { default as relToAbsChromPos } from './rel-to-abs-chrom-pos';
export { default as removeClass } from './remove-class';
export { default as resetD3BrushStyle } from './reset-d3-brush-style';
export { default as rgbToHex } from './rgb-to-hex';
export { default as scalesCenterAndK } from './scales-center-and-k';
export { default as scalesToGenomeLoci } from './scales-to-genome-loci';
export { default as showMousePosition } from './show-mouse-position';
export { default as some } from './some';
export { default as sum } from './sum';
export { default as svgLine } from './svg-line';
export { default as throttleAndDebounce } from './throttle-and-debounce';
export { default as tileToCanvas } from './tile-to-canvas';
export { default as timeout } from './timeout';
export { default as totalTrackPixelHeight } from './total-track-pixel-height';
export { default as toVoid } from './to-void';
export { default as trimTrailingSlash } from './trim-trailing-slash';
export { default as valueToColor } from './value-to-color';
export { default as expandCombinedTracks } from './expand-combined-tracks';
export { default as segmentsToRows } from './segments-to-rows';
export { default as visitPositionedTracks } from './visit-positioned-tracks';
export { default as visitTracks } from './visit-tracks';
export { default as DenseDataExtrema1D } from './DenseDataExtrema1D';
export { default as DenseDataExtrema2D } from './DenseDataExtrema2D';
export { default as getAggregationFunction } from './get-aggregation-function';
export { default as selectedItemsToSize } from './selected-items-to-size';
export { default as IS_TRACK_RANGE_SELECTABLE } from './is-track-range-selectable';

export {
  getTrackObjectFromHGC,
  getTrackRenderer,
  getTiledPlot,
} from './get-higlass-components';

// We want to remove following lines eventually. However, we need these at the moment since
// available-for-plugins.js complains about uninitialized objects due to the current cyclic dependencies.
export {
  changeOptions,
  waitForJsonComplete,
  waitForTilesLoaded,
  waitForTransitionsFinished,
  mountHGComponent,
  mountHGComponentAsync,
  removeHGComponent,
} from '../test-helpers';
export { default as trackUtils } from '../track-utils';
